@@ -1,12 +1,7 @@
 .onAttach <- function(libName,pkgName) {
   options(RDocumentation.timeOut = 3)
   options(help_type = "html")
-  
-  if (interactive()) {
-    ask_questions()
-  } else {
-    # just do the override
-    enable_override()
-  }
+  enable_rdocs()
+  ask_questions()
 }
 
